@@ -2,13 +2,20 @@ import queue
 import json
 from awsiot.greengrasscoreipc.model import UnauthorizedError, ComponentUpdatePolicyEvents
 from .IPC import IPC
+from .dev_IPC import dev_IPC
 import time as t
 import logging
 import traceback
 import os
 
-# Reuse one IPC client
-IPC_client = IPC()
+logger = logging.getLogger(__name__)
+
+
+# Code is running in Greengrass
+if os.getenv("AWS_IOT_THING_NAME"):
+    IPC_client = IPC()
+else:
+    IPC_client = dev_IPC()
 
 """
 The IPC client V1 can't send new requests or process new event messages while the thread
@@ -69,7 +76,7 @@ class IPCThreadPublish():
                 try:
                     IPC_client.publish(data["topic"], data["message"])
                 except:
-                    pass
+                    logger.exception("Can't publish message: [%s]", data)
 
 
 class IPCThreadPublishToCore():
@@ -165,4 +172,4 @@ class SubscribeComponentUpdate():
                 logging.info(f"Applied update for deployment {event.post_update_event.deployment_id}")
                 self.updated_queue.put({"applied": True})
         except:
-            traceback.print_exc()
\ No newline at end of file
+            traceback.print_exc()
